summaryrefslogtreecommitdiffstats
path: root/src/debputy/plugin/debputy/private_api.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/debputy/plugin/debputy/private_api.py')
-rw-r--r--src/debputy/plugin/debputy/private_api.py22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/debputy/plugin/debputy/private_api.py b/src/debputy/plugin/debputy/private_api.py
index 3b5087b..6d60333 100644
--- a/src/debputy/plugin/debputy/private_api.py
+++ b/src/debputy/plugin/debputy/private_api.py
@@ -897,7 +897,7 @@ def register_install_rules(api: DebputyPluginInitializerProvider) -> None:
With these two things in mind, it behaves just like the `install` rule.
Note: It is often worth considering to use a more specialized version of the `install-docs`
rule when one such is available. If you are looking to install an example or a manpage,
consider whether `install-examples` or `install-man` might be a better fit for your
use-case.
"""
@@ -1066,18 +1066,18 @@ def register_install_rules(api: DebputyPluginInitializerProvider) -> None:
_install_man_rule_handler,
source_format=_with_alt_form(ParsedInstallManpageRuleSourceFormat),
inline_reference_documentation=reference_documentation(
- title="Install manpages (`install-man`)",
+ title="Install man pages (`install-man`)",
description=textwrap.dedent(
"""\
Install rule for installing manpages similar to `dh_installman`. It is a shorthand
over the generic `install` rule with the following key features:
1) The rule can only match files (notably, symlinks cannot be matched by this rule).
- 2) The `dest-dir` is computed per source file based on the manpage's section and
+ 2) The `dest-dir` is computed per source file based on the man page's section and
language.
3) The `into` parameter can be omitted as long as there is a exactly one non-`udeb`
package listed in `debian/control`.
- 4) The rule comes with manpage specific attributes such as `language` and `section`
+ 4) The rule comes with man page specific attributes such as `language` and `section`
for when the auto-detection is insufficient.
5) The rule comes with pre-defined conditional logic for skipping the rule under
`DEB_BUILD_OPTIONS=nodoc`, so you do not have to write that conditional yourself.
@@ -1111,7 +1111,7 @@ def register_install_rules(api: DebputyPluginInitializerProvider) -> None:
textwrap.dedent(
"""\
Either a package name or a list of package names for which these paths should be
installed as manpages. This key is conditional on whether there are multiple (non-`udeb`)
binary packages listed in `debian/control`. When there is only one (non-`udeb`) binary
package, then that binary is the default for `into`. Otherwise, the key is required.
"""
@@ -1122,7 +1122,7 @@ def register_install_rules(api: DebputyPluginInitializerProvider) -> None:
textwrap.dedent(
"""\
If provided, it must be an integer between 1 and 9 (both inclusive), defining the
section the manpages belong overriding any auto-detection that `debputy` would
have performed.
"""
),
@@ -1134,8 +1134,8 @@ def register_install_rules(api: DebputyPluginInitializerProvider) -> None:
If provided, it must be either a 2 letter language code (such as `de`), a 5 letter
language + dialect code (such as `pt_BR`), or one of the special keywords `C`,
`derive-from-path`, or `derive-from-basename`. The default is `derive-from-path`.
- - When `language` is `C`, then the manpages are assumed to be "untranslated".
- - When `language` is a language code (with or without dialect), then all manpages
+ - When `language` is `C`, then the man pages are assumed to be "untranslated".
+ - When `language` is a language code (with or without dialect), then all man pages
matched will be assumed to be translated to that concrete language / dialect.
- When `language` is `derive-from-path`, then `debputy` attempts to derive the
language from the path (`man/<language>/man<section>`). This matches the
@@ -1216,7 +1216,7 @@ def register_install_rules(api: DebputyPluginInitializerProvider) -> None:
requested by the packager or a search directory that `debputy`
provided automatically (such as `debian/tmp`). Listing other paths
will make `debputy` report an error.
- - Note that the `path` or `paths` must match at least one entry in
+ - Note that the `path` or `paths` must match at least one entry in
any of the search directories unless *none* of the search directories
exist (or the condition in `required-when` evaluates to false). When
none of the search directories exist, the discard rule is silently
@@ -2604,7 +2604,7 @@ def _install_man_rule_handler(
)
if section is None and any(s.raw_match_rule.endswith(".gz") for s in sources):
raise ManifestParseException(
- "Sorry, compressed manpages are not supported without an explicit `section` definition at the moment."
+ "Sorry, compressed man pages are not supported without an explicit `section` definition at the moment."
" This limitation may be removed in the future. Problematic definition from"
f' {attribute_path["sources"]}'
)
@@ -897,7 +897,7 @@ def register_install_rules(api: DebputyPluginInitializerProvider) -> None:
With these two things in mind, it behaves just like the `install` rule.
Note: It is often worth considering to use a more specialized version of the `install-docs`
- rule when one such is available. If you are looking to install an example or a manpage,
+ rule when one such is available. If you are looking to install an example or a man page,
consider whether `install-examples` or `install-man` might be a better fit for your
use-case.
@@ -1066,18 +1066,18 @@ def register_install_rules(api: DebputyPluginInitializerProvider) -> None:
description=textwrap.dedent(
"""\
- Install rule for installing manpages similar to `dh_installman`. It is a shorthand
+ Install rule for installing man pages similar to `dh_installman`. It is a shorthand
over the generic `install` rule with the following key features:
1) The rule can only match files (notably, symlinks cannot be matched by this rule).
@@ -1111,7 +1111,7 @@ def register_install_rules(api: DebputyPluginInitializerProvider) -> None:
"""\
Either a package name or a list of package names for which these paths should be
- installed as manpages. This key is conditional on whether there are multiple (non-`udeb`)
+ installed as man pages. This key is conditional on whether there are multiple (non-`udeb`)
binary packages listed in `debian/control`. When there is only one (non-`udeb`) binary
package, then that binary is the default for `into`. Otherwise, the key is required.
@@ -1122,7 +1122,7 @@ def register_install_rules(api: DebputyPluginInitializerProvider) -> None:
"""\
If provided, it must be an integer between 1 and 9 (both inclusive), defining the
- section the manpages belong overriding any auto-detection that `debputy` would
+ section the man pages belong overriding any auto-detection that `debputy` would
have performed.
"""